Learn R Programming

xyloplot (version 2.0)

left_right_xylo: Left-right xyloplots

Description

Create a xyloplot with independent histograms on the left and right hand side of each pivot.

Usage

left_right_xylo(lhs, rhs, ...)

Arguments

lhs

A set of values to use as the left-hand side histograms (see xyloplot for details on admissible types)..

rhs

As lhs for the right-hand side.

...

Additional arguments passed to xyloplot.

Value

A "xyloplot" object.

See Also

xyloplot