Learn R Programming

xyloplot (version 2.0)

xyloplot-package: A Method for Creating Xylophone-Like Frequency Density Plots

Description

A method for creating vertical histograms sharing a y-axis using base graphics.

Arguments

Details

xyloplot provides a generic method for plotting frequency density plots in the style of histograms akin to violin plots for numeric vectors and lists of numeric vectors.

Examples

Run this code
# NOT RUN {
  xyloplot(rnorm(1000))
  xyloplot(lapply(1:3, function(mean) rnorm(mean=mean, n=1000)), col=rainbow(3))
# }

Run the code above in your browser using DataLab