xyloplot-package: A Method for Creating Xylophone-Like Frequency Density Plots
Description
A method for creating vertical histograms sharing a y-axis using
base graphics.
Arguments
Details
xyloplot provides a generic method for plotting frequency density plots in the style of histograms akin to violin plots for numeric vectors and lists of numeric vectors.